@@ -292,7 +292,7 @@
 <context>
     <name>Fm::AppChooserComboBox</name>
     <message>
-        <location filename="../../appchoosercombobox.cpp" line="78"/>
+        <location filename="../../appchoosercombobox.cpp" line="67"/>
         <source>Customize</source>
         <translation>Vlastní</translation>
     </message>
@@ -308,25 +308,35 @@
 <context>
     <name>Fm::CreateNewMenu</name>
     <message>
-        <location filename="../../createnewmenu.cpp" line="29"/>
+        <location filename="../../createnewmenu.cpp" line="30"/>
         <source>Folder</source>
         <translation>Adresář</translation>
     </message>
     <message>
-        <location filename="../../createnewmenu.cpp" line="33"/>
+        <location filename="../../createnewmenu.cpp" line="34"/>
         <source>Blank File</source>
         <translation>Prázdný soubor</translation>
     </message>
 </context>
+<context>
+    <name>Fm::DirListJob</name>
+    <message>
+        <location filename="../../core/dirlistjob.cpp" line="45"/>
+        <source>The specified directory &apos;%1&apos; is not valid</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Fm::DirTreeModel</name>
     <message>
-        <location filename="../../dirtreemodelitem.cpp" line="76"/>
+        <location filename="../../dirtreemodelitem.cpp" line="85"/>
         <source>Loading...</source>
         <translation>Nahrává se...</translation>
     </message>
     <message>
-        <location filename="../../dirtreemodelitem.cpp" line="207"/>
+        <location filename="../../dirtreemodelitem.cpp" line="268"/>
+        <location filename="../../dirtreemodelitem.cpp" line="312"/>
+        <location filename="../../dirtreemodelitem.cpp" line="410"/>
         <source>&lt;No sub folders&gt;</source>
         <translation>&lt;Žádné podsložky&gt;</translation>
     </message>
@@ -334,17 +344,17 @@
 <context>
     <name>Fm::DirTreeView</name>
     <message>
-        <location filename="../../dirtreeview.cpp" line="207"/>
+        <location filename="../../dirtreeview.cpp" line="211"/>
         <source>Open in New T&amp;ab</source>
         <translation>Otevřít v novém &amp;panelu</translation>
     </message>
     <message>
-        <location filename="../../dirtreeview.cpp" line="211"/>
+        <location filename="../../dirtreeview.cpp" line="215"/>
         <source>Open in New Win&amp;dow</source>
         <translation>Otevřít v novém &amp;okně</translation>
     </message>
     <message>
-        <location filename="../../dirtreeview.cpp" line="216"/>
+        <location filename="../../dirtreeview.cpp" line="220"/>
         <source>Open in Termina&amp;l</source>
         <translation>Otevřít v &amp;terminálu</translation>
     </message>
@@ -352,7 +362,7 @@
 <context>
     <name>Fm::DndActionMenu</name>
     <message>
-        <location filename="../../dndactionmenu.cpp" line="33"/>
+        <location filename="../../dndactionmenu.cpp" line="32"/>
         <source>Copy here</source>
         <translation>Kopírovat sem</translation>
     </message>
@@ -362,12 +372,12 @@
         <translation>Přesunout sem</translation>
     </message>
     <message>
-        <location filename="../../dndactionmenu.cpp" line="37"/>
+        <location filename="../../dndactionmenu.cpp" line="38"/>
         <source>Create symlink here</source>
         <translation>Vytvořit zde odkaz</translation>
     </message>
     <message>
-        <location filename="../../dndactionmenu.cpp" line="39"/>
+        <location filename="../../dndactionmenu.cpp" line="41"/>
         <source>Cancel</source>
         <translation>Zrušit</translation>
     </message>
@@ -375,7 +385,7 @@
 <context>
     <name>Fm::EditBookmarksDialog</name>
     <message>
-        <location filename="../../editbookmarksdialog.cpp" line="96"/>
+        <location filename="../../editbookmarksdialog.cpp" line="98"/>
         <source>New bookmark</source>
         <translation>Nová záložka</translation>
     </message>
@@ -383,14 +393,14 @@
 <context>
     <name>Fm::ExecFileDialog</name>
     <message>
-        <location filename="../../execfiledialog.cpp" line="39"/>
+        <location filename="../../execfiledialog.cpp" line="40"/>
         <source>This text file &apos;%1&apos; seems to be an executable script.
 What do you want to do with it?</source>
         <translation>Zdá se, že tento textový soubor &apos;%1&apos; je spustitelný skript.
 Co s ním chcete dělat?</translation>
     </message>
     <message>
-        <location filename="../../execfiledialog.cpp" line="44"/>
+        <location filename="../../execfiledialog.cpp" line="45"/>
         <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
         <translation>Tento soubor &apos;%1&apos; je spustitelný. Chcete jej spustit?</translation>
     </message>
@@ -398,83 +408,83 @@ Co s ním chcete dělat?</translation>
 <context>
     <name>Fm::FileMenu</name>
     <message>
-        <location filename="../../filemenu.cpp" line="95"/>
+        <location filename="../../filemenu.cpp" line="82"/>
         <source>Open</source>
         <translation>Otevřít</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="133"/>
+        <location filename="../../filemenu.cpp" line="120"/>
         <source>Create &amp;New</source>
         <translation>Vytvořit &amp;nový</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="153"/>
+        <location filename="../../filemenu.cpp" line="139"/>
         <source>&amp;Restore</source>
         <translation>O&amp;bnovit</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="159"/>
+        <location filename="../../filemenu.cpp" line="145"/>
         <source>Cut</source>
         <translation>Vyjmout</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="163"/>
+        <location filename="../../filemenu.cpp" line="149"/>
         <source>Copy</source>
         <translation>Kopírovat</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="167"/>
+        <location filename="../../filemenu.cpp" line="153"/>
         <source>Paste</source>
         <translation>Vložit</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="171"/>
-        <location filename="../../filemenu.cpp" line="371"/>
+        <location filename="../../filemenu.cpp" line="157"/>
+        <location filename="../../filemenu.cpp" line="348"/>
         <source>&amp;Move to Trash</source>
         <translation>Přesunout do &amp;koše</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="319"/>
+        <location filename="../../filemenu.cpp" line="297"/>
         <source>Output</source>
         <translation>Výstup</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="371"/>
+        <location filename="../../filemenu.cpp" line="348"/>
         <source>&amp;Delete</source>
         <translation>&amp;Smazat</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="175"/>
+        <location filename="../../filemenu.cpp" line="161"/>
         <source>Rename</source>
         <translation>Přejmenovat</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="99"/>
+        <location filename="../../filemenu.cpp" line="86"/>
         <source>Open With...</source>
         <translation>Otevřít v ...</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="127"/>
+        <location filename="../../filemenu.cpp" line="114"/>
         <source>Other Applications</source>
         <translation>Ostatní programy</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="207"/>
+        <location filename="../../filemenu.cpp" line="188"/>
         <source>Extract to...</source>
         <translation>Rozbalit do ...</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="212"/>
+        <location filename="../../filemenu.cpp" line="193"/>
         <source>Extract Here</source>
         <translation>Rozbalit sem</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="218"/>
+        <location filename="../../filemenu.cpp" line="199"/>
         <source>Compress</source>
         <translation>Komprimovat</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="228"/>
+        <location filename="../../filemenu.cpp" line="209"/>
         <source>Properties</source>
         <translation>Vlastnosti</translation>
     </message>
@@ -482,30 +492,30 @@ Co s ním chcete dělat?</translation>
 <context>
     <name>Fm::FileOperation</name>
     <message>
-        <location filename="../../fileoperation.cpp" line="220"/>
+        <location filename="../../fileoperation.cpp" line="227"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="221"/>
+        <location filename="../../fileoperation.cpp" line="228"/>
         <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
 Do you want to delete them instead?</source>
         <translation>Některé soubory nemohou být přesunuty do koše, protože příslušné souborové systémy nepodporují tuto operaci.
 Chceš je odstranit trvale?</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="262"/>
-        <location filename="../../fileoperation.cpp" line="278"/>
+        <location filename="../../fileoperation.cpp" line="270"/>
+        <location filename="../../fileoperation.cpp" line="287"/>
         <source>Confirm</source>
         <translation>Potvrdit</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="263"/>
+        <location filename="../../fileoperation.cpp" line="271"/>
         <source>Do you want to delete the selected files?</source>
         <translation>Chceš smazat vybrané soubory?</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="279"/>
+        <location filename="../../fileoperation.cpp" line="288"/>
         <source>Do you want to move the selected files to trash can?</source>
         <translation>Chceš přesunout vybrané soubory do koše?</translation>
     </message>
@@ -583,7 +593,7 @@ Chceš je odstranit trvale?</translation>
         <translation>Obnovit následující soubory z koše:</translation>
     </message>
     <message>
-        <location filename="../../fileoperationdialog.cpp" line="137"/>
+        <location filename="../../fileoperationdialog.cpp" line="134"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
@@ -591,47 +601,57 @@ Chceš je odstranit trvale?</translation>
 <context>
     <name>Fm::FilePropsDialog</name>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="154"/>
+        <location filename="../../filepropsdialog.cpp" line="156"/>
         <source>View folder content</source>
         <translation>Zobrazit obsah složky</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="155"/>
+        <location filename="../../filepropsdialog.cpp" line="157"/>
         <source>View and modify folder content</source>
         <translation>Zobrazit a měnit obsah složky</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="159"/>
+        <location filename="../../filepropsdialog.cpp" line="161"/>
         <source>Read</source>
         <translation>Čtení</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="160"/>
+        <location filename="../../filepropsdialog.cpp" line="162"/>
         <source>Read and write</source>
         <translation>Čtení a zápis</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="162"/>
+        <location filename="../../filepropsdialog.cpp" line="164"/>
         <source>Forbidden</source>
         <translation>Zakázáno</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="266"/>
+        <location filename="../../filepropsdialog.cpp" line="281"/>
         <source>Files of different types</source>
         <translation>Soubory různých typů</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="296"/>
+        <location filename="../../filepropsdialog.cpp" line="304"/>
         <source>Multiple Files</source>
         <translation>Více souborů</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="424"/>
+        <location filename="../../filepropsdialog.cpp" line="380"/>
+        <source>Select an icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../filepropsdialog.cpp" line="382"/>
+        <source>Images (*.png *.xpm *.svg *.svgz )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../filepropsdialog.cpp" line="478"/>
         <source>Apply changes</source>
         <translation>Použít změny</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="425"/>
+        <location filename="../../filepropsdialog.cpp" line="479"/>
         <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
         <translation>Chcete tyto změny použít na všechny soubory a podsložky?</translation>
     </message>
@@ -639,17 +659,17 @@ Chceš je odstranit trvale?</translation>
 <context>
     <name>Fm::FileSearchDialog</name>
     <message>
-        <location filename="../../filesearchdialog.cpp" line="122"/>
+        <location filename="../../filesearchdialog.cpp" line="128"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../../filesearchdialog.cpp" line="122"/>
+        <location filename="../../filesearchdialog.cpp" line="128"/>
         <source>You should add at least one directory to search.</source>
         <translation>Přidej aspoň jeden adresář k prohledání.</translation>
     </message>
     <message>
-        <location filename="../../filesearchdialog.cpp" line="129"/>
+        <location filename="../../filesearchdialog.cpp" line="135"/>
         <source>Select a folder</source>
         <translation>Vybrat adresář</translation>
     </message>
@@ -687,65 +707,65 @@ Chceš je odstranit trvale?</translation>
         <translation>Zobrazit skryté</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="100"/>
+        <location filename="../../foldermenu.cpp" line="94"/>
         <source>Folder Pr&amp;operties</source>
         <translation>Vlastnosti sl&amp;ožky</translation>
     </message>
     <message>
         <source>Folder</source>
-        <translation>Adresář</translation>
+        <translation type="vanished">Adresář</translation>
     </message>
     <message>
         <source>Blank File</source>
-        <translation>Prázdný soubor</translation>
+        <translation type="vanished">Prázdný soubor</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="141"/>
+        <location filename="../../foldermenu.cpp" line="137"/>
         <source>Output</source>
         <translation>Výstup</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="166"/>
+        <location filename="../../foldermenu.cpp" line="160"/>
         <source>By File Name</source>
         <translation>Podle jména</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="167"/>
+        <location filename="../../foldermenu.cpp" line="161"/>
         <source>By Modification Time</source>
         <translation>Podle času</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="168"/>
+        <location filename="../../foldermenu.cpp" line="162"/>
         <source>By File Size</source>
         <translation>Podle velikosti</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="169"/>
+        <location filename="../../foldermenu.cpp" line="163"/>
         <source>By File Type</source>
         <translation>Podle typu</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="170"/>
+        <location filename="../../foldermenu.cpp" line="164"/>
         <source>By File Owner</source>
         <translation>Podle vlastníka</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="182"/>
+        <location filename="../../foldermenu.cpp" line="176"/>
         <source>Ascending</source>
         <translation>Vzestupně</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="187"/>
+        <location filename="../../foldermenu.cpp" line="181"/>
         <source>Descending</source>
         <translation>sestupně</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="202"/>
+        <location filename="../../foldermenu.cpp" line="198"/>
         <source>Folder First</source>
         <translation>Adresáře jako první</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="211"/>
+        <location filename="../../foldermenu.cpp" line="208"/>
         <source>Case Sensitive</source>
         <translation>Zohlednit velikost písmen</translation>
     </message>
@@ -753,27 +773,27 @@ Chceš je odstranit trvale?</translation>
 <context>
     <name>Fm::FolderModel</name>
     <message>
-        <location filename="../../foldermodel.cpp" line="248"/>
+        <location filename="../../foldermodel.cpp" line="242"/>
         <source>Name</source>
         <translation>Jméno</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="251"/>
+        <location filename="../../foldermodel.cpp" line="245"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="254"/>
+        <location filename="../../foldermodel.cpp" line="248"/>
         <source>Size</source>
         <translation>Velikost</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="257"/>
+        <location filename="../../foldermodel.cpp" line="251"/>
         <source>Modified</source>
         <translation>Změněno</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="260"/>
+        <location filename="../../foldermodel.cpp" line="254"/>
         <source>Owner</source>
         <translation>Vlastník</translation>
     </message>
@@ -799,45 +819,58 @@ Chceš je odstranit trvale?</translation>
         <translation>&amp;Připojit</translation>
     </message>
 </context>
+<context>
+    <name>Fm::PathBar</name>
+    <message>
+        <location filename="../../pathbar.cpp" line="126"/>
+        <source>&amp;Edit Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../pathbar.cpp" line="129"/>
+        <source>&amp;Copy Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Fm::PlacesModel</name>
     <message>
-        <location filename="../../placesmodel.cpp" line="41"/>
+        <location filename="../../placesmodel.cpp" line="44"/>
         <source>Places</source>
         <translation>Místa</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="49"/>
+        <location filename="../../placesmodel.cpp" line="52"/>
         <source>Desktop</source>
         <translation>Plocha</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="245"/>
+        <location filename="../../placesmodel.cpp" line="231"/>
         <source>Trash</source>
         <translation>Koš</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="58"/>
+        <location filename="../../placesmodel.cpp" line="60"/>
         <source>Computer</source>
         <translation>Počítač</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="71"/>
+        <location filename="../../placesmodel.cpp" line="72"/>
         <source>Applications</source>
         <translation>Aplikace</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="83"/>
+        <location filename="../../placesmodel.cpp" line="81"/>
         <source>Network</source>
         <translation>Síť</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="91"/>
+        <location filename="../../placesmodel.cpp" line="88"/>
         <source>Devices</source>
         <translation>Zařízení</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="144"/>
+        <location filename="../../placesmodel.cpp" line="142"/>
         <source>Bookmarks</source>
         <translation>Záložky</translation>
     </message>
@@ -845,7 +878,7 @@ Chceš je odstranit trvale?</translation>
 <context>
     <name>Fm::PlacesView</name>
     <message>
-        <location filename="../../placesview.cpp" line="362"/>
+        <location filename="../../placesview.cpp" line="370"/>
         <source>Empty Trash</source>
         <translation>Vysypat koš</translation>
     </message>
@@ -858,48 +891,48 @@ Chceš je odstranit trvale?</translation>
         <translation type="obsolete">Smazat</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="350"/>
+        <location filename="../../placesview.cpp" line="356"/>
         <source>Open in New Tab</source>
         <translation>Otevřít v novém panelu</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="353"/>
+        <location filename="../../placesview.cpp" line="359"/>
         <source>Open in New Window</source>
         <translation>Otevřít v novém okně</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="371"/>
+        <location filename="../../placesview.cpp" line="379"/>
         <source>Move Bookmark Up</source>
         <translation>Přesunout záložku nahoru</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="376"/>
+        <location filename="../../placesview.cpp" line="384"/>
         <source>Move Bookmark Down</source>
         <translation>Přesunout záložku dolů</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="380"/>
+        <location filename="../../placesview.cpp" line="388"/>
         <source>Rename Bookmark</source>
         <translation>Přejmenovat záložku</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="383"/>
+        <location filename="../../placesview.cpp" line="391"/>
         <source>Remove Bookmark</source>
         <translation>Odstranit záložku</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="392"/>
-        <location filename="../../placesview.cpp" line="409"/>
+        <location filename="../../placesview.cpp" line="400"/>
+        <location filename="../../placesview.cpp" line="417"/>
         <source>Unmount</source>
         <translation>Odpojit</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="396"/>
+        <location filename="../../placesview.cpp" line="404"/>
         <source>Mount</source>
         <translation>Připojit</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="402"/>
+        <location filename="../../placesview.cpp" line="410"/>
         <source>Eject</source>
         <translation>Vysunout</translation>
     </message>
@@ -938,26 +971,22 @@ Změněno: %2</translation>
 <context>
     <name>Fm::SidePane</name>
     <message>
-        <location filename="../../sidepane.cpp" line="47"/>
-        <location filename="../../sidepane.cpp" line="127"/>
+        <location filename="../../sidepane.cpp" line="46"/>
         <source>Places</source>
         <translation>Místa</translation>
     </message>
     <message>
-        <location filename="../../sidepane.cpp" line="48"/>
-        <location filename="../../sidepane.cpp" line="129"/>
+        <location filename="../../sidepane.cpp" line="47"/>
         <source>Directory Tree</source>
         <translation>Strom adresářů</translation>
     </message>
     <message>
-        <location filename="../../sidepane.cpp" line="137"/>
         <source>Shows list of common places, devices, and bookmarks in sidebar</source>
-        <translation>Zobrazit seznam obvyklých míst, zařízení a záložek v postranní liště</translation>
+        <translation type="vanished">Zobrazit seznam obvyklých míst, zařízení a záložek v postranní liště</translation>
     </message>
     <message>
-        <location filename="../../sidepane.cpp" line="139"/>
         <source>Shows tree of directories in sidebar</source>
-        <translation>Zobrazit strom adresářů v postranní liště</translation>
+        <translation type="vanished">Zobrazit strom adresářů v postranní liště</translation>
     </message>
 </context>
 <context>
@@ -1011,59 +1040,64 @@ Změněno: %2</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../utilities.cpp" line="149"/>
-        <location filename="../../utilities.cpp" line="225"/>
-        <location filename="../../mountoperation.cpp" line="185"/>
-        <location filename="../../filepropsdialog.cpp" line="450"/>
-        <location filename="../../filelauncher.cpp" line="117"/>
+        <location filename="../../utilities.cpp" line="143"/>
+        <location filename="../../utilities.cpp" line="232"/>
+        <location filename="../../mountoperation.cpp" line="186"/>
+        <location filename="../../filepropsdialog.cpp" line="503"/>
+        <location filename="../../filelauncher.cpp" line="139"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="120"/>
+        <location filename="../../utilities.cpp" line="149"/>
         <source>Rename File</source>
         <translation>Přejmenovat soubor</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="121"/>
+        <location filename="../../utilities.cpp" line="150"/>
         <source>Please enter a new name:</source>
         <translation>Prosím zadej nové jméno:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="161"/>
+        <location filename="../../utilities.cpp" line="174"/>
         <source>Create Folder</source>
         <translation>Vytvořit adresář</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="166"/>
+        <location filename="../../utilities.cpp" line="179"/>
         <source>Please enter a new file name:</source>
         <translation>Prosím zadej nové jméno souboru:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="167"/>
+        <location filename="../../utilities.cpp" line="180"/>
         <source>New text file</source>
         <translation>Nový textový soubor</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="171"/>
+        <location filename="../../utilities.cpp" line="184"/>
         <source>Please enter a new folder name:</source>
         <translation>Prosím zadej nové jméno adresáře:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="172"/>
+        <location filename="../../utilities.cpp" line="185"/>
         <source>New folder</source>
         <translation>Nový adresář</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="177"/>
+        <location filename="../../utilities.cpp" line="190"/>
         <source>Enter a name for the new %1:</source>
         <translation>Zadej jméno pro nový %1:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="162"/>
+        <location filename="../../utilities.cpp" line="175"/>
         <source>Create File</source>
         <translation>Vytvořit soubor</translation>
     </message>
+    <message>
+        <location filename="../../filepropsdialog.cpp" line="520"/>
+        <source>Custom Icon Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RenameDialog</name>
