@@ -132,14 +132,14 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="70"/>
+        <location filename="../../lxqtpowermanager.cpp" line="74"/>
         <source>LXQt Power Manager Error</source>
-        <translation type="unfinished">Збій менеджера живлення LXQt</translation>
+        <translation>Збій менеджера живлення LXQt</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="70"/>
+        <location filename="../../lxqtpowermanager.cpp" line="74"/>
         <source>Hibernate failed.</source>
-        <translation type="unfinished">Не вдалося приспати.</translation>
+        <translation>Не вдалося приспати.</translation>
     </message>
 </context>
 <context>
@@ -153,93 +153,93 @@
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="112"/>
+        <location filename="../../lxqtpowermanager.cpp" line="117"/>
         <source>Hibernate</source>
         <translation>Приспати</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="119"/>
+        <location filename="../../lxqtpowermanager.cpp" line="124"/>
         <source>Suspend</source>
         <translation>Призупинити</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="126"/>
+        <location filename="../../lxqtpowermanager.cpp" line="131"/>
         <source>Reboot</source>
         <translation>Перезавантажити</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="133"/>
+        <location filename="../../lxqtpowermanager.cpp" line="138"/>
         <source>Shutdown</source>
         <translation>Вимкнути</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="140"/>
+        <location filename="../../lxqtpowermanager.cpp" line="145"/>
         <source>Logout</source>
         <translation>Вийти</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="152"/>
+        <location filename="../../lxqtpowermanager.cpp" line="157"/>
         <source>LXQt Session Suspend</source>
         <translation>Призупинити комп’ютер</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="153"/>
+        <location filename="../../lxqtpowermanager.cpp" line="158"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
         <translation>Дійсно призупинити комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи не збережеться.</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="162"/>
+        <location filename="../../lxqtpowermanager.cpp" line="167"/>
         <source>LXQt Session Hibernate</source>
         <translation>Приспати комп’ютер</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="163"/>
+        <location filename="../../lxqtpowermanager.cpp" line="168"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
         <translation>Дійсно приспати комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи збережеться.</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="172"/>
+        <location filename="../../lxqtpowermanager.cpp" line="177"/>
         <source>LXQt Session Reboot</source>
         <translation>Перезавантажити комп’ютер</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="173"/>
+        <location filename="../../lxqtpowermanager.cpp" line="178"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
         <translation>Дійсно перезавантажити комп’ютер? Усю незбережену роботу буде втрачено...</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="182"/>
+        <location filename="../../lxqtpowermanager.cpp" line="187"/>
         <source>LXQt Session Shutdown</source>
         <translation>Вимкнути комп’ютер</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="183"/>
+        <location filename="../../lxqtpowermanager.cpp" line="188"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation>Дійсно вимкнути комп’ютер? Усю незбережену роботу буде втрачено...</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="192"/>
+        <location filename="../../lxqtpowermanager.cpp" line="197"/>
         <source>LXQt Session Logout</source>
         <translation>Вийти з сеансу LXQt</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="193"/>
+        <location filename="../../lxqtpowermanager.cpp" line="198"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation>Дійсно завершити сеанс? Усю незбережену роботу буде втрачено...</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="201"/>
         <location filename="../../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../../lxqtpowermanager.cpp" line="211"/>
         <source>LXQt Power Manager Error</source>
         <translation>Збій менеджера живлення LXQt</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="201"/>
+        <location filename="../../lxqtpowermanager.cpp" line="206"/>
         <source>Hibernate failed.</source>
         <translation>Не вдалося приспати.</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../../lxqtpowermanager.cpp" line="211"/>
         <source>Suspend failed.</source>
         <translation>Не вдалося призупинити.</translation>
     </message>
@@ -247,26 +247,26 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="51"/>
+        <location filename="../../lxqtscreensaver.cpp" line="236"/>
         <source>Lock Screen</source>
         <translation>Заблокувати екран</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="77"/>
+        <location filename="../../lxqtscreensaver.cpp" line="156"/>
         <source>Screen Saver Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Помилка зберігача екрану</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="83"/>
-        <location filename="../../lxqtscreensaver.cpp" line="89"/>
-        <location filename="../../lxqtscreensaver.cpp" line="96"/>
+        <location filename="../../lxqtscreensaver.cpp" line="162"/>
+        <location filename="../../lxqtscreensaver.cpp" line="168"/>
+        <location filename="../../lxqtscreensaver.cpp" line="175"/>
         <source>Screen Saver Activation Error</source>
         <translation>Збій запуску зберігача екрану</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="97"/>
+        <location filename="../../lxqtscreensaver.cpp" line="176"/>
         <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Сталася помилка під час запуску зберігача екрану. Невідома помилка - недокументоване значення виводу xdg-screensaver: %1. </translation>
     </message>
     <message>
         <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
@@ -281,17 +281,17 @@
         <translation type="vanished">Стався збій при запуску зберігача екрану. Не вдалося запустити xdg-screensaver.</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="78"/>
+        <location filename="../../lxqtscreensaver.cpp" line="157"/>
         <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
         <translation>Стався збій при запуску зберігача екрану. В аргументах xdg-screensaver синтаксична помилка.</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="84"/>
+        <location filename="../../lxqtscreensaver.cpp" line="163"/>
         <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
         <translation>Стався збій при запуску зберігача екрану. Впевніться, що xscreensaver коректно встановлено та запущено.</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="90"/>
+        <location filename="../../lxqtscreensaver.cpp" line="169"/>
         <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
         <translation>Стався збій при запуску зберігача екрану. Не вдалося виконати дію &quot;activate&quot;. Впевніться, що xscreensaver коректно встановлено та запущено.</translation>
     </message>
@@ -314,20 +314,20 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
         <source>Power Manager Error</source>
         <translation>Збій менеджера живлення</translation>
     </message>
     <message>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
         <translation>QDBusInterface недійсний</translation>
     </message>
     <message>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
         <translation>Збій менеджера живлення (виклик D-BUS)</translation>
     </message>
