@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1">
+<TS version="2.1" language="de">
 <context>
     <name>Fm::FontButton</name>
     <message>
@@ -17,88 +17,88 @@
 <context>
     <name>MainDialog</name>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1012"/>
+        <location filename="../../ui_obconf.h" line="1012"/>
         <source>Window Manager Preferences</source>
         <translation>Fenstermanager Openbox :: Einstellungen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1017"/>
+        <location filename="../../ui_obconf.h" line="1017"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1019"/>
+        <location filename="../../ui_obconf.h" line="1019"/>
         <source>Appearance</source>
         <translation>Erscheinungsbild</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1021"/>
+        <location filename="../../ui_obconf.h" line="1021"/>
         <source>Font</source>
         <translation>Schrift</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1023"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1038"/>
+        <location filename="../../ui_obconf.h" line="1023"/>
+        <location filename="../../ui_obconf.h" line="1038"/>
         <source>Windows</source>
         <translation>Fenster</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1025"/>
+        <location filename="../../ui_obconf.h" line="1025"/>
         <source>Move &amp; Resize</source>
         <translation>Verschieben und Größe ändern</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1027"/>
+        <location filename="../../ui_obconf.h" line="1027"/>
         <source>Mouse</source>
         <translation>Maus</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1029"/>
+        <location filename="../../ui_obconf.h" line="1029"/>
         <source>Desktops</source>
         <translation>Arbeitsflächen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1031"/>
+        <location filename="../../ui_obconf.h" line="1031"/>
         <source>Margins</source>
         <translation>Ränder</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1033"/>
+        <location filename="../../ui_obconf.h" line="1033"/>
         <source>Dock</source>
         <translation>Dock</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1036"/>
+        <location filename="../../ui_obconf.h" line="1036"/>
         <source>&amp;Install a new theme...</source>
         <translation>Neues Thema &amp;installieren...</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1037"/>
+        <location filename="../../ui_obconf.h" line="1037"/>
         <source>Create a theme &amp;archive (.obt)...</source>
         <translation>Themenarchiv &amp;erstellen (.obt)...</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1039"/>
+        <location filename="../../ui_obconf.h" line="1039"/>
         <source>&amp;Windows retain a border when undecorated</source>
         <translation>Undekorierte Fenster um&amp;randen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1040"/>
+        <location filename="../../ui_obconf.h" line="1040"/>
         <source>A&amp;nimate iconify and restore</source>
         <translation>Minimieren und Wiederherstellen &amp;animieren</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1041"/>
+        <location filename="../../ui_obconf.h" line="1041"/>
         <source>Window Titles</source>
         <translation>Fenstertitel</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1042"/>
+        <location filename="../../ui_obconf.h" line="1042"/>
         <source>Button order:</source>
         <translation>Anordnung der Schaltflächen (Knöpfe):</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1043"/>
+        <location filename="../../ui_obconf.h" line="1043"/>
         <source>N: Window icon
 L: Window label (Title)
 I: Iconify (Minimize)
@@ -115,472 +115,472 @@ S: Einrollen
 D: auf allen Arbeitsflächen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1056"/>
+        <location filename="../../ui_obconf.h" line="1056"/>
         <source>&amp;Active window title: </source>
         <translation>Fenstertitel &amp;aktives Fenster</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1057"/>
+        <location filename="../../ui_obconf.h" line="1057"/>
         <source>&amp;Inactive window title: </source>
         <translation>Fenstertitel &amp;inaktives Fenster</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1058"/>
+        <location filename="../../ui_obconf.h" line="1058"/>
         <source>Menu &amp;header: </source>
         <translation>Menü - &amp;Überschrift</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1059"/>
+        <location filename="../../ui_obconf.h" line="1059"/>
         <source>&amp;Menu Item: </source>
         <translation>Menü - einzelne &amp;Einträge</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1060"/>
+        <location filename="../../ui_obconf.h" line="1060"/>
         <source>Active &amp;On-screen display: </source>
         <translation>A&amp;ktive Bildschirmanzeige</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1061"/>
+        <location filename="../../ui_obconf.h" line="1061"/>
         <source>Inactive O&amp;n-screen display: </source>
         <translation>I&amp;naktive Bildschirmanzeige</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1062"/>
+        <location filename="../../ui_obconf.h" line="1062"/>
         <source>Focus &amp;new windows when they appear</source>
         <translation>&amp;Neue Fenster beim Erscheinen fokussieren</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1063"/>
+        <location filename="../../ui_obconf.h" line="1063"/>
         <source>&amp;Place new windows under the mouse pointer</source>
         <translation>Neue Fenster unter dem Mauszeiger &amp;platzieren</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1064"/>
+        <location filename="../../ui_obconf.h" line="1064"/>
         <source>&amp;Center new windows when they are placed</source>
         <translation>Neue Fenster &amp;zentrieren</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1065"/>
+        <location filename="../../ui_obconf.h" line="1065"/>
         <source>Prefer to place new windows &amp;on:</source>
         <translation>Neue Fenster &amp;vorzugsweise platzieren auf</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1068"/>
+        <location filename="../../ui_obconf.h" line="1068"/>
         <source>All monitors</source>
         <translation>allen Bildschirmen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1069"/>
+        <location filename="../../ui_obconf.h" line="1069"/>
         <source>The active monitor</source>
         <translation>dem aktiven Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1070"/>
+        <location filename="../../ui_obconf.h" line="1070"/>
         <source>The monitor with the mouse</source>
         <translation>dem Bildschirm, wo sich der Mauszeiger befindet</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1071"/>
+        <location filename="../../ui_obconf.h" line="1071"/>
         <source>Primary monitor</source>
         <translation>dem primären Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1073"/>
+        <location filename="../../ui_obconf.h" line="1073"/>
         <source>Primary Monitor</source>
         <translation>Primärer Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1074"/>
+        <location filename="../../ui_obconf.h" line="1074"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
         <translation>Der primäre Bildschirm ist derjenige, auf dem Dialoge wie der zum Wechsel von Fenstern angezeigt werden.</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1075"/>
+        <location filename="../../ui_obconf.h" line="1075"/>
         <source>Primary &amp;monitor:</source>
         <translation>P&amp;rimärer Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1078"/>
+        <location filename="../../ui_obconf.h" line="1078"/>
         <source>Fixed Monitor</source>
         <translation>Festgelegter Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1079"/>
+        <location filename="../../ui_obconf.h" line="1079"/>
         <source>Active Monitor</source>
         <translation>aktiver Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1080"/>
+        <location filename="../../ui_obconf.h" line="1080"/>
         <source>Monitor With Mouse Pointer</source>
         <translation>Bildschirm, wo sich der Mauszeiger befindet</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1082"/>
+        <location filename="../../ui_obconf.h" line="1082"/>
         <source>&amp;Fixed monitor:</source>
         <translation>&amp;Festgelegter Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1083"/>
+        <location filename="../../ui_obconf.h" line="1083"/>
         <source>Moving and Resizing Windows</source>
         <translation>Verschieben und Größenänderung von Fenstern</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1084"/>
+        <location filename="../../ui_obconf.h" line="1084"/>
         <source>Update the window contents while &amp;resizing</source>
         <translation>Fensterinhalt während &amp;Größenänderungen anzeigen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1085"/>
+        <location filename="../../ui_obconf.h" line="1085"/>
         <source>Drag &amp;threshold distance:</source>
         <translation>Abstand beim &amp;Verschieben</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1086"/>
+        <location filename="../../ui_obconf.h" line="1086"/>
         <source>Amount of resistance against other &amp;windows:</source>
         <translation>Widerstand gegenüber anderen &amp;Fenstern</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1087"/>
+        <location filename="../../ui_obconf.h" line="1087"/>
         <source>Amount of resistance against screen &amp;edges:</source>
         <translation>Widerstand gegenüber &amp;Bildschirmrändern</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1088"/>
+        <location filename="../../ui_obconf.h" line="1088"/>
         <source>&amp;Amount of time to wait before switching:</source>
         <translation>Ver&amp;zögerung vor dem Arbeitsflächenwechsel</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1089"/>
+        <location filename="../../ui_obconf.h" line="1089"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
         <translation>Arbeitsfläche beim Verschieben des Fensters über ihren Rand &amp;wechseln</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1090"/>
+        <location filename="../../ui_obconf.h" line="1090"/>
         <source>Information Dialog</source>
         <translation>Informationsdialog</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1093"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1100"/>
+        <location filename="../../ui_obconf.h" line="1093"/>
+        <location filename="../../ui_obconf.h" line="1100"/>
         <source>Centered</source>
         <translation>Fenstermitte</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1094"/>
+        <location filename="../../ui_obconf.h" line="1094"/>
         <source>From left edge</source>
         <translation>Vom linken Rand</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1095"/>
+        <location filename="../../ui_obconf.h" line="1095"/>
         <source>From right edge</source>
         <translation>Vom rechten Rand</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1097"/>
+        <location filename="../../ui_obconf.h" line="1097"/>
         <source>Fixed &amp;y position:</source>
         <translation>Festgelegte &amp;y-Position (Pixel)</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1101"/>
+        <location filename="../../ui_obconf.h" line="1101"/>
         <source>From top edge</source>
         <translation>Vom oberen Rand</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1102"/>
+        <location filename="../../ui_obconf.h" line="1102"/>
         <source>From bottom edge</source>
         <translation>Vom unteren Rand</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1104"/>
+        <location filename="../../ui_obconf.h" line="1104"/>
         <source>Information dialog&apos;s &amp;position:</source>
         <translation>&amp;Position des Informationsdialogs</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1105"/>
+        <location filename="../../ui_obconf.h" line="1105"/>
         <source>Fixed &amp;x position:</source>
         <translation>Festgelegte &amp;x-Position (Pixel)</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1106"/>
+        <location filename="../../ui_obconf.h" line="1106"/>
         <source>Show &amp;information dialog:</source>
         <translation>&amp;Informationsdialog anzeigen:</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1109"/>
+        <location filename="../../ui_obconf.h" line="1109"/>
         <source>When resizing terminal windows</source>
         <translation>Bei Größenänderung von Terminalfenstern</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1110"/>
+        <location filename="../../ui_obconf.h" line="1110"/>
         <source>Always</source>
         <translation>Immer</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1111"/>
+        <location filename="../../ui_obconf.h" line="1111"/>
         <source>Never</source>
         <translation>Nie</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1115"/>
+        <location filename="../../ui_obconf.h" line="1115"/>
         <source>Centered on the window</source>
         <translation>Fenstermitte</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1116"/>
+        <location filename="../../ui_obconf.h" line="1116"/>
         <source>Above the window</source>
         <translation>Oberhalb des Fensters</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1117"/>
+        <location filename="../../ui_obconf.h" line="1117"/>
         <source>Fixed position on screen</source>
         <translation>Feste Position auf dem Bildschirm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1119"/>
+        <location filename="../../ui_obconf.h" line="1119"/>
         <source>Focusing Windows</source>
         <translation>Fokussieren von Fenstern</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1120"/>
+        <location filename="../../ui_obconf.h" line="1120"/>
         <source>Focus windows when the mouse pointer moves over them</source>
         <translation>Fenster &amp;fokussieren, wenn sich der Mauszeiger über ihnen befindet</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1121"/>
+        <location filename="../../ui_obconf.h" line="1121"/>
         <source>&amp;Delay before focusing and raising windows:</source>
         <translation>&amp;Verzögerung vor dem Fokussieren und Hervorheben</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1122"/>
+        <location filename="../../ui_obconf.h" line="1122"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
         <translation>Beim &amp;Wechsel von Arbeitsflächen Fokus unter den Mauszeiger bringen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1123"/>
+        <location filename="../../ui_obconf.h" line="1123"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
         <translation>Fokus &amp;unter die Maus bringen, wenn diese nicht bewegt wird</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1124"/>
+        <location filename="../../ui_obconf.h" line="1124"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
         <translation>Fenster &amp;hervorheben, wenn sich der Mauszeiger darüber befindet</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1125"/>
+        <location filename="../../ui_obconf.h" line="1125"/>
         <source>Titlebar</source>
         <translation>Fenstertitel</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1126"/>
+        <location filename="../../ui_obconf.h" line="1126"/>
         <source>Double click on the &amp;titlebar:</source>
         <translation>Doppelklick auf den Fenster&amp;titel</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1129"/>
+        <location filename="../../ui_obconf.h" line="1129"/>
         <source>Maximizes the window</source>
         <translation>Maximiert das Fenster</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1130"/>
+        <location filename="../../ui_obconf.h" line="1130"/>
         <source>Shades the window</source>
         <translation>Rollt das Fenster ein</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1132"/>
+        <location filename="../../ui_obconf.h" line="1132"/>
         <source>Double click ti&amp;me:</source>
         <translation>&amp;Intervall für Doppelklick</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1133"/>
+        <location filename="../../ui_obconf.h" line="1133"/>
         <source>&amp;Show a notification when switching desktops</source>
         <translation>Benachrichtigung beim Arbeitsflächen&amp;wechsel anzeigen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1134"/>
+        <location filename="../../ui_obconf.h" line="1134"/>
         <source>&amp;Amount of time to show the notification for:</source>
         <translation>&amp;Dauer, für die die Benachrichtigung angezeigt wird</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1135"/>
+        <location filename="../../ui_obconf.h" line="1135"/>
         <source>&amp;Number of desktops: </source>
         <translation>An&amp;zahl an Arbeitsflächen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1136"/>
+        <location filename="../../ui_obconf.h" line="1136"/>
         <source>&amp;Desktop names:</source>
         <translation>&amp;Bezeichnungen der Arbeitsflächen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1137"/>
+        <location filename="../../ui_obconf.h" line="1137"/>
         <source>Desktop Margins</source>
         <translation>Arbeitsflächenränder</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1138"/>
+        <location filename="../../ui_obconf.h" line="1138"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
         <translation>Arbeitsflächenränder sind reservierte Bereiche am Rand des Bildschirms. Neue Fenster werden dort nicht platziert und maximierte Fenster überdecken diese Bereiche nicht.</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1139"/>
+        <location filename="../../ui_obconf.h" line="1139"/>
         <source>Left:</source>
         <translation>Links</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1140"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1142"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1144"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1146"/>
+        <location filename="../../ui_obconf.h" line="1140"/>
+        <location filename="../../ui_obconf.h" line="1142"/>
+        <location filename="../../ui_obconf.h" line="1144"/>
+        <location filename="../../ui_obconf.h" line="1146"/>
         <source>px</source>
         <translation>Pixel (px)</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1141"/>
+        <location filename="../../ui_obconf.h" line="1141"/>
         <source>Top:</source>
         <translation>Oben</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1143"/>
+        <location filename="../../ui_obconf.h" line="1143"/>
         <source>Right:</source>
         <translation>Rechts</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1145"/>
+        <location filename="../../ui_obconf.h" line="1145"/>
         <source>Bottom:</source>
         <translation>Unten</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1147"/>
+        <location filename="../../ui_obconf.h" line="1147"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
         <translation>Das &quot;dock&quot; ist ein graphisches Objekt zum Vorhalten sogenannter dock-Anwendungen (&quot;dockapps&quot;), die z. B. eine Uhr oder Benachrichtigungen anzeigen können.
 Das dock wird erst nach dem Starten von dockapps sichtbar.</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1148"/>
+        <location filename="../../ui_obconf.h" line="1148"/>
         <source>Position</source>
         <translation>Position</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1149"/>
+        <location filename="../../ui_obconf.h" line="1149"/>
         <source>&amp;Position:</source>
         <translation>&amp;Position:</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1152"/>
+        <location filename="../../ui_obconf.h" line="1152"/>
         <source>Top Left</source>
         <translation>oben links</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1153"/>
+        <location filename="../../ui_obconf.h" line="1153"/>
         <source>Top</source>
         <translation>oben zentriert</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1154"/>
+        <location filename="../../ui_obconf.h" line="1154"/>
         <source>Top Right</source>
         <translation>oben rechts</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1155"/>
+        <location filename="../../ui_obconf.h" line="1155"/>
         <source>Left</source>
         <translation>mitte (vertikal) links</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1156"/>
+        <location filename="../../ui_obconf.h" line="1156"/>
         <source>Right</source>
         <translation>mitte (vertikal) rechts</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1157"/>
+        <location filename="../../ui_obconf.h" line="1157"/>
         <source>Bottom Left</source>
         <translation>unten rechts</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1158"/>
+        <location filename="../../ui_obconf.h" line="1158"/>
         <source>Bottom</source>
         <translation>unten zentriert</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1159"/>
+        <location filename="../../ui_obconf.h" line="1159"/>
         <source>Bottom Right</source>
         <translation>unten rechts</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1160"/>
+        <location filename="../../ui_obconf.h" line="1160"/>
         <source>Floating</source>
         <translation>manuell festgelegte Position</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1162"/>
+        <location filename="../../ui_obconf.h" line="1162"/>
         <source>&amp;Floating position:</source>
         <translation>&amp;manuell festgelegte Position</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1163"/>
+        <location filename="../../ui_obconf.h" line="1163"/>
         <source>x</source>
         <translation>x</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1164"/>
+        <location filename="../../ui_obconf.h" line="1164"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
         <translation>Positionieren von &amp;Fenstern über dem dock erlauben</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1165"/>
+        <location filename="../../ui_obconf.h" line="1165"/>
         <source>&amp;Orientation: </source>
         <translation>Ausrichtung</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1168"/>
+        <location filename="../../ui_obconf.h" line="1168"/>
         <source>Vertical</source>
         <translation>vertikal</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1169"/>
+        <location filename="../../ui_obconf.h" line="1169"/>
         <source>Horizontal</source>
         <translation>horizontal</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1171"/>
+        <location filename="../../ui_obconf.h" line="1171"/>
         <source>Stacking</source>
         <translation>Ebenen</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1172"/>
+        <location filename="../../ui_obconf.h" line="1172"/>
         <source>Keep dock &amp;above other windows</source>
         <translation>immer im &amp;Vordergrund</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1173"/>
+        <location filename="../../ui_obconf.h" line="1173"/>
         <source>A&amp;llow dock to be both above and below windows</source>
         <translation>analog &amp;regulären Fenstern (Vorder- und Hintergrund möglich)</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1174"/>
+        <location filename="../../ui_obconf.h" line="1174"/>
         <source>Keep dock &amp;below other windows</source>
         <translation>immer im &amp;Hintergrund</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1175"/>
+        <location filename="../../ui_obconf.h" line="1175"/>
         <source>Hiding</source>
         <translation>Ausblenden</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1176"/>
+        <location filename="../../ui_obconf.h" line="1176"/>
         <source>&amp;Delay before hiding:</source>
         <translation>Verzögerung vor dem &amp;Ausblenden</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1177"/>
+        <location filename="../../ui_obconf.h" line="1177"/>
         <source>Delay before &amp;showing:</source>
         <translation>Verzögerung vor dem &amp;Einblenden</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1178"/>
+        <location filename="../../ui_obconf.h" line="1178"/>
         <source>&amp;Hide off screen</source>
         <translation>Ausblenden a&amp;ktivieren</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1179"/>
+        <location filename="../../ui_obconf.h" line="1179"/>
         <source>About</source>
         <translation>&amp;Über ObConf-Qt</translation>
     </message>
@@ -779,7 +779,7 @@ Optionen:
         <translation>--config-file benötigt ein Argument</translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="235"/>
+        <location filename="../../obconf-qt.cpp" line="239"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
@@ -794,13 +794,13 @@ Message: %1</source>
         <translation type="vanished">--config-file benötigt ein Argument</translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="221"/>
-        <location filename="../../obconf-qt.cpp" line="237"/>
+        <location filename="../../obconf-qt.cpp" line="225"/>
+        <location filename="../../obconf-qt.cpp" line="241"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="222"/>
+        <location filename="../../obconf-qt.cpp" line="226"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Datei rc.xml konnte nicht geladen werden. Möglicher Weise wurde Openbox nicht korrekt installiert.</translation>
     </message>
